@@ -8,7 +8,7 @@ module INotify
   # @private
   module Native
     extend FFI::Library
-    ffi_lib "c"
+    ffi_lib FFI::Library::LIBC
 
     # The C struct describing an inotify event.
     #
